==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/HorizontalRangeCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RangeCategorySeriesDescriptionMetadata } from "./RangeCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let HorizontalRangeCategorySeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class HorizontalRangeCategorySeriesDescriptionMetadata extends Base {
        static b(a) {
            if (HorizontalRangeCategorySeriesDescriptionMetadata.a == null) {
                HorizontalRangeCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HorizontalRangeCategorySeriesDescriptionMetadata.c(HorizontalRangeCategorySeriesDescriptionMetadata.a);
            }
            if (a.k(HorizontalRangeCategorySeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(HorizontalRangeCategorySeriesDescriptionMetadata.a);
        }
        static c(a) {
            RangeCategorySeriesDescriptionMetadata.c(a);
            a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
            a.item("XAxisRef@nameBinding", "true");
            a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
            a.item("YAxisRef@nameBinding", "true");
            a.item("LowMemberAsLegendLabel", "String");
            a.item("HighMemberAsLegendLabel", "String");
            a.item("LowMemberAsLegendUnit", "String");
            a.item("HighMemberAsLegendUnit", "String");
        }
        static d(a) {
            HorizontalRangeCategorySeriesDescriptionMetadata.b(a);
            a.ac("HorizontalRangeCategorySeries", HorizontalRangeCategorySeriesDescriptionMetadata.a);
        }
    }
    HorizontalRangeCategorySeriesDescriptionMetadata.$t = markType(HorizontalRangeCategorySeriesDescriptionMetadata, 'HorizontalRangeCategorySeriesDescriptionMetadata');
    HorizontalRangeCategorySeriesDescriptionMetadata.a = null;
    return HorizontalRangeCategorySeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/HorizontalRangeCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RangeCategorySeriesDescriptionMetadata } from "./RangeCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let HorizontalRangeCategorySeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class HorizontalRangeCategorySeriesDescriptionMetadata extends Base {
        static b(a) {
            if (HorizontalRangeCategorySeriesDescriptionMetadata.a == null) {
                HorizontalRangeCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HorizontalRangeCategorySeriesDescriptionMetadata.c(HorizontalRangeCategorySeriesDescriptionMetadata.a);
            }
            if (a.k(HorizontalRangeCategorySeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(HorizontalRangeCategorySeriesDescriptionMetadata.a);
        }
        static c(a) {
            RangeCategorySeriesDescriptionMetadata.c(a);
            a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
            a.item("XAxisRef@nameBinding", "true");
            a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
            a.item("YAxisRef@nameBinding", "true");
            a.item("LowMemberAsLegendLabel", "String");
            a.item("HighMemberAsLegendLabel", "String");
            a.item("LowMemberAsLegendUnit", "String");
            a.item("HighMemberAsLegendUnit", "String");
        }
        static d(a) {
            HorizontalRangeCategorySeriesDescriptionMetadata.b(a);
            a.ad("HorizontalRangeCategorySeries", HorizontalRangeCategorySeriesDescriptionMetadata.a);
        }
    }
    HorizontalRangeCategorySeriesDescriptionMetadata.$t = markType(HorizontalRangeCategorySeriesDescriptionMetadata, 'HorizontalRangeCategorySeriesDescriptionMetadata');
    HorizontalRangeCategorySeriesDescriptionMetadata.a = null;
    return HorizontalRangeCategorySeriesDescriptionMetadata;
})();
